#
# spec file for package ghc-http-client
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-client
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.1.1
Release:        lp151.1.3
Summary:        An HTTP client engine
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-mime-types-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-zlib-devel
%endif

%description
Hackage documentation generation is not reliable. For up to date documentation,
please see: <http://www.stackage.org/package/http-client>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Thu Feb 21 2019 psimons@suse.com
- Update http-client to version 0.6.1.1.
  [#]# 0.6.1.1
  * Ensure that `Int` parsing doesn't overflow [#383](https://github.com/snoyberg/http-client/issues/383)
* Tue Jan 15 2019 psimons@suse.com
- Update http-client to version 0.6.1.
  [#]# 0.6.1
  * Add `setUriEither` to `Network.HTTP.Client.Internal`
* Thu Jan 10 2019 psimons@suse.com
- Update http-client to version 0.6.0.
  [#]# 0.6.0
  * Generalize `renderParts` over arbitrary applicative functors.  One particular
    use case that is enabled by this change is that now `renderParts` can be used
    in pure code by using it in combination with `runIdentity`.
* Mon Nov 19 2018 psimons@suse.com
- Update http-client to version 0.5.14.
  [#] Changelog for http-client
  [#]# 0.5.14
  * Omit port for `getUri` when protocol is `http` and port is `80`, or when
    protocol is `https` and port is `443`
  * Sending requests with invalid headers now throws InvalidRequestHeader exception
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update http-client to version 0.5.13.1.
  [#]# 0.5.13.1
  * Add a workaround for a cabal bug [haskell-infra/hackage-trustees#165](https://github.com/haskell-infra/hackage-trustees/issues/165)
  [#]# 0.5.13
  * Adds `setRequestCheckStatus` and `throwErrorStatusCodes` functions.
    See [#304](https://github.com/snoyberg/http-client/issues/304)
  * Add `withConnection` function.
    See [#352](https://github.com/snoyberg/http-client/pull/352).
* Mon May 14 2018 psimons@suse.com
- Update http-client to version 0.5.12.1 revision 1.
  * Make the chunked transfer-encoding detection case insensitive
    [#303](https://github.com/snoyberg/http-client/pull/303)
  * Remove some unneeded language extensions
  * Mark older versions of GHC as unsupported
  * Added `requestFromURI` and `requestFromURI_` functions.
  * Fixed non-TLS connections going though proxy [#337](https://github.com/snoyberg/http-client/issues/337)
  * Replaced `base64-bytestring` dependency with `memory`.
  * New function to partial escape query strings
  * Add `Semigroup` instances for GHC 8.4 [#320](https://github.com/snoyberg/http-client/pull/320)
  * Switch to the new STM-based manager
    [#254](https://github.com/snoyberg/http-client/pull/254)
  * Redact sensitive headers [#318](https://github.com/snoyberg/http-client/pull/318)
  * Code cleanup/delete dead code
  * Compat with Win32 2.6 [#309](https://github.com/snoyberg/http-client/issues/309)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.5.7.0.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 0.5.6.1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.5.5 with cabal2obs.
* Tue Nov 29 2016 psimons@suse.com
- Update to version 0.4.31.2 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.4.31.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 mimi.vx@gmail.com
- update to version 0.4.31 revision 0
  * Added length validation for RequestBodyStream
* Sun Jul  3 2016 mimi.vx@gmail.com
- update to 0.4.30
  * Deprecate parseUrl
  * Add parseUrlThrow, parseRequest, and parseRequest_
* Fri Jun 17 2016 mimi.vx@gmail.com
- update to 0.4.29
  * Changed the order of connecting a socket and tweaking a socket, such that
    the socket tweaking callback now happen before connecting.
  * add setRequestIgnoreStatus
  * Added missing Host: HTTP header for https CONNECT
  * Fix: Redirects will be followed in httpRaw' when reusing a dead connection
* Sat Apr 16 2016 mimi.vx@gmail.com
- update to 0.4.28
  * Add support for including request method in URL
  * requestManagerOverride
  * RequestBodyIO
* Tue Apr 12 2016 mimi.vx@gmail.com
- update to 0.4.27.1
  * Incorrect idle connection count in HTTP manager
* Fri Jan 22 2016 mimi.vx@gmail.com
- update to 0.4.27
  * Enable managerModifyRequest to modify checkStatus
* Thu Dec 24 2015 mimi.vx@gmail.com
- update to 0.4.26.2
  * Fix compilation for GHC 7.4
* Thu Dec 17 2015 mimi.vx@gmail.com
- update to 0.4.26.1
  * Make sure we never read from or write to closed socket
* Sun Dec 13 2015 mimi.vx@gmail.com
- update to 0.4.25
  * Don't error out when response body flushing fails
* Sun Sep 27 2015 mimi.vx@gmail.com
- update to 0.4.24
  * Use a new TlsExceptionHostPort exception to indicate the host and port of the
  server we were trying to connect to when a TLS exception occurred.
* Sun Sep 20 2015 mimi.vx@gmail.com
- update to 0.4.23
  * Case insensitive cookie domains
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 0.4.22.1
  * ProxyConnectException now returns Right HttpException.
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 0.4.21
  * Support no_proxy environment variable
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 0.4.20
  * Expose brReadSome
* Thu Aug 13 2015 mimi.vx@gmail.com
- update to 0.4.19
  * Move HasHttpManager from http-conduit to http-client
  * Chunked request bodies use less TCP packets
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 0.4.18.1
  * Case insensitive proxy environment variables
  * Deprecate closeManager
* Mon Jul 13 2015 mimi.vx@gmail.com
- update to 0.4.16
  * Proxy auth for HTTPS
* Mon Jul  6 2015 mimi.vx@gmail.com
- update to 0.4.15
  * Support proxy authentication in environment variables
  * Ignore empty http_proxy
  * Support for auth via url
* Sun Jun 21 2015 mimi.vx@gmail.com
- update to 0.4.12
  * Added IsString RequestBody instance
* Mon Jun  8 2015 mimi.vx@gmail.com
- update to 0.4.11.3
  * Fix getUri to insert "?" to uriQuery when necessary.
* Mon May  4 2015 mimi.vx@gmail.com
- update to 0.4.11.2
  + Removed publicsuffixlist dependency, see [Github discussion](https://github.com/litherum/publicsuffixlist/pull/7)
* Wed Apr 22 2015 mimi.vx@gmail.com
- initial commit
